summaryrefslogtreecommitdiff
path: root/src/gallium/auxiliary/pipebuffer/pb_bufmgr.h
diff options
context:
space:
mode:
authorJosé Fonseca <jfonseca@vmware.com>2009-02-24 15:49:21 +0000
committerJosé Fonseca <jfonseca@vmware.com>2009-02-24 15:49:21 +0000
commit0be216c526c29726a73a26a37dcd5a00cfbefc86 (patch)
treeca9b67116c19d78215b561e987d49e81b8fff8e8 /src/gallium/auxiliary/pipebuffer/pb_bufmgr.h
parent8f3c1cddaa9c307f70fca0e1a917397a7d85c238 (diff)
pipebuffer: Allow asymmetric guard sizes for under/overflow detection.
Diffstat (limited to 'src/gallium/auxiliary/pipebuffer/pb_bufmgr.h')
-rw-r--r--src/gallium/auxiliary/pipebuffer/pb_bufmgr.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/gallium/auxiliary/pipebuffer/pb_bufmgr.h b/src/gallium/auxiliary/pipebuffer/pb_bufmgr.h
index fec8db91c7..74077f8277 100644
--- a/src/gallium/auxiliary/pipebuffer/pb_bufmgr.h
+++ b/src/gallium/auxiliary/pipebuffer/pb_bufmgr.h
@@ -200,10 +200,11 @@ pb_ondemand_manager_create(struct pb_manager *provider);
/**
* Debug buffer manager to detect buffer under- and overflows.
*
* Band size should be a multiple of the largest alignment
*/
struct pb_manager *
-pb_debug_manager_create(struct pb_manager *provider, size_t band_size);
+pb_debug_manager_create(struct pb_manager *provider,
+ size_t underflow_size, size_t overflow_size);
#ifdef __cplusplus
@@ -200,10 +200,11 @@ pb_ondemand_manager_create(struct pb_manager *provider);
* Debug buffer manager to detect buffer under- and overflows.
*
- * Band size should be a multiple of the largest alignment
+ * Under/overflow sizes should be a multiple of the largest alignment
*/
struct pb_manager *